#!/bin/bash
# Convert a Metop CCSDS file to EPS Level 0 format (Metopizer 3.51.1 version)
# The input file should contain all APIDs for HKTM, AVHRR, HIRS, IASI, MHS, and AMSU-A
# Metop codes are as follows: Metop-A = M02, Metop-B = M01, Metop-C = M03

# Set inputs
metop_file=$1
metop_code=$2

# Create MPHR config file
echo "# MetOpizer L0 Production Configuration File
product_type=HRP
spacecraft_id=$metop_code
instrument_model=1
processing_centre=EARS
processing_mode=N
disposition_mode=O
processor_major_version=2
processor_minor_version=0
receiving_ground_station=GAN" > mphr.config

# Create HKTM config file
echo "# MetOpizer CCSDS APID configuration file
HKTM:      1-3,6" > ccsds_hktm.config

# Create Metop sensor config file
echo "# MetOpizer CCSDS APID configuration file
HKTM:      1-3,6
AVHRR:     65-70,103,104
HIRS:      38
IASI:      130,135,140,145,150,160,180
MHS:       34
AMSUA:     39,40" > ccsds_sensor.config

# Extract MMAM from HKTM
mkdir mmam
aapp_run.bash ccsds_to_l0 --config-apid ccsds_hktm.config --config-mphr mphr.config --generate-mmam mmam --in $metop_file --outdir . 

# Extract EPS Level 0 files and TLE (clock correction from MMAM will be applied)
mkdir input
aapp_run.bash ccsds_to_l0 --config-apid ccsds_sensor.config --config-mphr mphr.config --use-mmam mmam --generate-tle --in $metop_file --outdir input 

# Move TLE file
mv TLE* input/tle.txt

# Cleanup
rm ccsds_hktm.config ccsds_sensor.config hktm*.l0 mmam/MMAM*xml mphr.config 
rmdir mmam
